@@ -15,14 +15,8 @@
 from __future__ import annotations
 
 import firefly as ff
-import os
 
 
-@ff.rest.crud(config={
-    'write': {
-        'scopes': [] if os.environ.get('ANONYMOUS_ACCESS', 'false') in (True, 'true', 1, '1')
-        else ['firefly_survey.Document.write']
-    }
-})
+@ff.rest.crud()
 class Document(ff.MetaAggregate):
     pass
